@@ -92,7 +92,7 @@ gvisWelcomeMessage <- function(){
   paste("\n",     
         "Welcome to googleVis version ", packageDescription("googleVis")$Version, "\n",
         "\n",
-        "Please read the Google API Terms of Use\n",
+        "Please read Google's Terms of Use\n",
         "before you start using the package:\n",
         "https://developers.google.com/terms/\n",
         "\n",
@@ -100,7 +100,7 @@ gvisWelcomeMessage <- function(){
         display,
         "\n",
         "See the googleVis package vignettes for more details,\n",
-        "or visit http://github.com/mages/googleVis.\n",
+        "or visit https://mages.github.io/googleVis/.\n",
         "\n",               
         "To suppress this message use:\n",
         "suppressPackageStartupMessages(library(googleVis))\n",  
